@@ -17,19 +17,19 @@
 
 #include "timezoneconverter.h"
 #include <ktimezone.h>
-#include <ksystemtimezone.h>
-#include <kdebug.h>
 #include <QRegExp>
 #include <QStringList>
 #include "kolabformat/errorhandler.h"
+#include <QTimeZone>
 
 QString TimezoneConverter::normalizeTimezone(const QString& tz)
 {
-    KTimeZone timezone = KSystemTimeZones::zone(tz); //Needs ktimezoned (timezone daemon running) http://api.kde.org/4.x-api/kdelibs-apidocs/kdecore/html/classKSystemTimeZones.html
-    if (timezone.isValid()) {
+    if (QTimeZone::isTimeZoneIdAvailable(tz.toLatin1())) {
         return tz;
-    } else if (!KSystemTimeZones::isTimeZoneDaemonAvailable()) {
-        Error() << "ktimezoned is not available and required for timezone interpretation";
+    }
+    auto normalizedId = QTimeZone::windowsIdToDefaultIanaId(tz.toLatin1());
+    if (!normalizedId.isEmpty()) {
+        return normalizedId;
     }
     //We're dealing with an invalid or unknown timezone, try to parse it
     QString guessedTimezone = fromCityName(tz);
@@ -39,13 +39,6 @@ QString TimezoneConverter::normalizeTimezone(const QString& tz)
     if (guessedTimezone.isEmpty()) {
         guessedTimezone = fromGMTOffsetTimezone(tz);
     }
-    if (guessedTimezone.isEmpty()) {
-        //slower but also finds outdated zones
-        timezone = KSystemTimeZones::readZone(tz);
-        if (timezone.isValid()) {
-            return tz;
-        }
-    }
     Debug() << "Guessed timezone and found: " << guessedTimezone;
     return guessedTimezone;
 }
@@ -58,14 +51,12 @@ QString TimezoneConverter::fromGMTOffsetTimezone(const QString& tz)
 
 QString TimezoneConverter::fromCityName(const QString& tz)
 {
-    const KTimeZones::ZoneMap zones = KSystemTimeZones::zones();
-    KTimeZones::ZoneMap::const_iterator it = zones.constBegin();
+    const auto zones = QTimeZone::availableTimeZoneIds();
     QHash<QString, QString> countryMap;
-    for(;it != zones.constEnd(); it++) {
-        const QString cityName = it.key().split('/').last();
-//         kDebug() << it.key() << it.value().name() << cityName;
+    for (auto zone : zones) {
+        const QString cityName = zone.split('/').last();
         Q_ASSERT(!countryMap.contains(cityName));
-        countryMap.insert(cityName, it.key());
+        countryMap.insert(cityName, zone);
     }
 
     QRegExp locationFinder("\\b([a-zA-Z])+\\b", Qt::CaseSensitive, QRegExp::RegExp2);
@@ -76,9 +67,9 @@ QString TimezoneConverter::fromCityName(const QString& tz)
             ++pos;
         }
         const QString location = locationFinder.capturedTexts().first();
-//         kDebug() << "location " << location;
+        qDebug() << "location " << location;
         if (countryMap.contains(location)) {
-//             kDebug() << "found match " << countryMap.value(location);
+            qDebug() << "found match " << countryMap.value(location);
             return countryMap.value(location);
         }
     }
