@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2012  Sofia Balicka <balicka@kolabsys.com>
+ * Copyright (C) 2014  Christian Mollekopf <mollekopf@kolabsys.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -19,16 +20,27 @@
 #define MIMEOBJECTTEST_H
 #include <QObject>
 
+/**
+ * Read-Write roundtrip test.
+ *
+ * Ensures we can read a mime message, serialize it again, and contents are still the same.
+ */
 class MIMEObjectTest: public QObject
 {
     Q_OBJECT
 
 private slots:
-    void initTestCase();
+    void testEvent_data();
     void testEvent();
-    void testJournal(); 
+    void testTodo_data();
+    void testTodo();
+    void testJournal_data();
+    void testJournal();
+    void testNote_data();
     void testNote();
+    void testContact_data();
     void testContact();
+    void testDistlist_data();
     void testDistlist();
 };
 #endif // MIMEOBJECTTEST_H
