@@ -32,10 +32,11 @@ private slots:
     void testFromHardcodedList_data();
     void testFromHardcodedList();
     void testKolabObjectWriter();
-    void testKolabObjectReader();
+    // void testKolabObjectReader();
     void testFindLegacyTimezone();
-    void testTimezoneDaemonAvailable();
+    void testIgnoreInvalidTimezone();
     void testUTCOffset();
+    void localTimezone();
 };
 
 #endif // TIMEZONETEST_H
